searchData={"items":[{"type":"module","title":"Jabol","doc":"Jabol is a lightweight schema and data persistence library for Elixir applications.\n\nThis module serves as the main entry point for the library's documentation.","ref":"Jabol.html"},{"type":"module","title":"Features - Jabol","doc":"- Schema definition system with field types\n- Simple repository pattern for database operations\n- Factory system for easy test data generation\n- Minimal configuration with sensible defaults\n\nFor detailed usage examples, see the README.md file.","ref":"Jabol.html#module-features"},{"type":"function","title":"Jabol.version/0","doc":"Returns the version of the Jabol library.","ref":"Jabol.html#version/0"},{"type":"module","title":"Jabol.Person","doc":"Defines a Person schema with basic attributes for database storage","ref":"Jabol.Person.html"},{"type":"module","title":"Jabol.Repo","doc":"Custom repository module for database operations.\nThis is a simplified implementation of database access functions.","ref":"Jabol.Repo.html"},{"type":"function","title":"Jabol.Repo.delete/1","doc":"Deletes a record from the database.","ref":"Jabol.Repo.html#delete/1"},{"type":"function","title":"Jabol.Repo.get/2","doc":"Retrieves a record from the database by ID.","ref":"Jabol.Repo.html#get/2"},{"type":"function","title":"Jabol.Repo.init/1","doc":"Initializes the repository with the given configuration.","ref":"Jabol.Repo.html#init/1"},{"type":"function","title":"Jabol.Repo.insert/2","doc":"Inserts a record into the database.","ref":"Jabol.Repo.html#insert/2"},{"type":"function","title":"Jabol.Repo.update/2","doc":"Updates a record in the database.","ref":"Jabol.Repo.html#update/2"},{"type":"module","title":"Jabol.Schema","doc":"Defines a Schema module for building database schemas.","ref":"Jabol.Schema.html"},{"type":"macro","title":"Jabol.Schema.field/3","doc":"Defines a field in the schema.","ref":"Jabol.Schema.html#field/3"},{"type":"macro","title":"Jabol.Schema.schema/2","doc":"Defines a schema with fields.","ref":"Jabol.Schema.html#schema/2"},{"type":"macro","title":"Jabol.Schema.timestamps/1","doc":"Defines timestamp fields (inserted_at and updated_at)","ref":"Jabol.Schema.html#timestamps/1"},{"type":"module","title":"Jabol.Factory","doc":"Factory module for creating test data","ref":"Jabol.Factory.html"},{"type":"function","title":"Jabol.Factory.build/2","doc":"Builds a struct of the given type with default attributes\nmerged with the provided attributes.","ref":"Jabol.Factory.html#build/2"},{"type":"function","title":"Jabol.Factory.build_list/3","doc":"Builds a list of structs","ref":"Jabol.Factory.html#build_list/3"},{"type":"function","title":"Jabol.Factory.create/2","doc":"Creates a test record through the repository","ref":"Jabol.Factory.html#create/2"},{"type":"function","title":"Jabol.Factory.get_defaults/1","doc":"Returns a map of default attributes for a given schema","ref":"Jabol.Factory.html#get_defaults/1"},{"type":"module","title":"Jabol.Config.Database","doc":"Database configuration helpers","ref":"Jabol.Config.Database.html"},{"type":"function","title":"Jabol.Config.Database.connection_string/0","doc":"Returns the connection string for the database","ref":"Jabol.Config.Database.html#connection_string/0"},{"type":"function","title":"Jabol.Config.Database.get_config/0","doc":"Returns the database configuration based on the environment","ref":"Jabol.Config.Database.html#get_config/0"},{"type":"extras","title":"Jabol","doc":"# Jabol\n\nJabol is a lightweight schema and data persistence library for Elixir applications. It provides a simple API for defining schemas, managing database connections, and performing CRUD operations.","ref":"readme.html"},{"type":"extras","title":"Features - Jabol","doc":"- Schema definition system with field types and validations\n- Simple repository pattern for database operations\n- Factory system for easy test data generation\n- Minimal configuration with sensible defaults","ref":"readme.html#features"},{"type":"extras","title":"Installation - Jabol","doc":"Add `jabol` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:jabol, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Jabol","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Configuration - Jabol","doc":"Set up your database configuration in `config.exs`:\n\n```elixir\nconfig :jabol, Jabol.Repo,\n  database: \"your_database\",\n  hostname: \"localhost\",\n  username: \"postgres\",\n  password: \"postgres\"\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Defining Schemas - Jabol","doc":"```elixir\ndefmodule MyApp.User do\n  use Jabol.Schema\n  \n  schema \"users\" do\n    field :name, :string\n    field :email, :string\n    field :age, :integer\n    \n    timestamps()\n  end\nend\n```","ref":"readme.html#defining-schemas"},{"type":"extras","title":"Database Operations - Jabol","doc":"```elixir\n# Insert a record\n{:ok, user} = Jabol.Repo.insert(MyApp.User, %{name: \"John\", email: \"john@example.com\", age: 30})\n\n# Get a record by ID\nuser = Jabol.Repo.get(MyApp.User, 1)\n\n# Update a record\n{:ok, updated_user} = Jabol.Repo.update(user, %{age: 31})\n\n# Delete a record\n{:ok, deleted_user} = Jabol.Repo.delete(user)\n```","ref":"readme.html#database-operations"},{"type":"extras","title":"Factory for Testing - Jabol","doc":"```elixir\n# Define defaults in your test helper\ndefmodule Jabol.Factory do\n  def get_defaults(MyApp.User) do\n    %{\n      name: \"Test User\",\n      email: \"test@example.com\",\n      age: 25\n    }\n  end\nend\n\n# In your tests\ntest \"user creation\" do\n  user = Jabol.Factory.build(MyApp.User, %{name: \"Custom Name\"})\n  assert user.name == \"Custom Name\"\n  assert user.email == \"test@example.com\"  # Default value\nend\n```","ref":"readme.html#factory-for-testing"},{"type":"extras","title":"Development - Jabol","doc":"To contribute to Jabol:\n\n1. Clone the repository\n2. Install dependencies with `mix deps.get`\n3. Run tests with `mix test`","ref":"readme.html#development"},{"type":"extras","title":"License - Jabol","doc":"This project is licensed under the MIT License - see the LICENSE file for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}